package pfg.gca;

import java.util.List;
import java.util.Properties;

import pfg.gca.collector.CollectorFactory;

/**
 * This class keeps track of GC information in the context of a single
 * loaded trace file.
 * <p>
 * @author Paul Glezen
 */
public class Context
{
   public static final String PROP_VERSION  = "version";
   public static final String PROP_TITLE    = "title";
   
   private static final String PROP_LAST_LOG = "lastFile";
   private static final String PROP_LAST_JDK = "lastJDK";

   private CollectorFactory    cf;
   private List            gcList;
   private PersistProps userProps = new PersistProps();
   private Properties    ctxProps = new Properties();
   
   /**
    * Get the name of the current verbose GC log file.
    * This property is stored using {@link PersistProps} so that
    * its value persists across program invocations.
    */
   public String getCurrentTraceFilename()
   {
      return userProps.getProperty(PROP_LAST_LOG);
   }

   /**
    * Get the current JDK type.
    * This property is stored using {@link PersistProps} so that
    * its value persists across program invocations.
    */
   public String getJdktype()
   {
      return userProps.getProperty(PROP_LAST_JDK);
   }

   public CollectorFactory getCollectorFactory()
   {
      return cf;
   }

   /**
    * Set the verbose GC file to use.
    * This property is persisted via {@link PersistProps} each
    * time it is set.  This allows it to persist across program
    * invocations.
    */
   public void setCurrentTraceFilename(String currentTraceFilename)
   {
      userProps.setProperty(PROP_LAST_LOG, currentTraceFilename);
   }

   /**
    * Set the JDK type to use.
    * This property is persisted via {@link PersistProps} each
    * time it is set.  This allows it to persist across program
    * invocations.
    */
   public void setJdktype(String jdktype)
   {
      userProps.setProperty(PROP_LAST_JDK, jdktype);
   }

   public void setCollectorFactory(CollectorFactory factory)
   {
      this.cf = factory;
   }
   
   public List getGCList()
   {
      return gcList;
   }
   
   public void setGCList(List l)
   {
      gcList = l;
   }
   
   public String toString()
   {
      StringBuffer result = new StringBuffer(250);
      result.append("jdktype  = " + getJdktype() + "\n");
      result.append("filename = " + getCurrentTraceFilename() + "\n");
      return result.toString();
   }
   
   public String getProperty(String propName) {
      return ctxProps.getProperty(propName);
   }

   public void addProps(Properties newProps)
   {
      ctxProps.putAll(newProps);
   }
}
