package pfg.gca;

import java.io.File;
import java.io.FileReader;
import java.io.IOException;
import java.io.InputStream;
import java.util.List;
import java.util.Properties;

import javax.swing.JFrame;

import pfg.gca.collector.CollectorFactory;
import pfg.gca.collector.ICollector;
import pfg.gca.models.HistogramModel;
import pfg.gca.swing.GCAFrame;
import pfg.gca.views.IntegerHistogram;
import pfg.gca.views.TextSummary;

/**
 * This class represents the launching point for the GC program.
 * <p>
 * @author Paul Glezen
 */
public class Main
{
   private static List gcList = null;
   private static Context context = null;

   /**
    * The entry point for the Swing version of GCA.
    */
   public static void main(String[] args)
   {
      String ui = null;
      String title = null;
      String version = null;
      context = new Context();
      context.setCollectorFactory(CollectorFactory.getInstance());
      
      //  Read initialization properties.
      //
      InputStream is = Main.class.getResourceAsStream("init.properties");
      Properties initProps = new Properties();
      if (is != null)
      {
         try
         {
            initProps.load(is);
            version = initProps.getProperty("version");
            title   = initProps.getProperty("title");
         }
         catch(IOException ioe)
         {
            System.out.println("Problem loading init properties: " + ioe);
         }
      }
      context.addProps(initProps);
      
      //  Interpret command-line arguments
      //
      switch (args.length)
      {
         case 2: cmdline(args);
                 break;
                 
         case 1: if (args[0].equals("swing"))
                 {
                    JFrame frame = new GCAFrame(context);
                 }
                 else
                 {
                     System.out.println("Unrecognized UI choice.");
                 }
                 break;
                 
        default: System.out.println();
                 System.out.println(title + " " + version);
                 System.out.println();
                 System.out.println("Usage: java -jar gca.jar <filename> <jdktype>");
                 System.out.println("   or");
                 System.out.println("       java -jar gca.jar <ui>");
                 System.out.println(" where");
                 System.out.println("         <filename> - verbosegc output file");
                 System.out.println("         <jdktype>  - JDK type string");
                 System.out.println("         <ui>       - swing");
                 System.out.println();
                 System.out.println("The first format is a command-line invocation.  The second");
                 System.out.println("format is a GUI invocation.  The supported JDKs are:");
                 String[] jdks = context.getCollectorFactory().getSupportedJDKs();
                 for (int i = 0; i < jdks.length; i++)
                 {
                    System.out.println("\t" + jdks[i]);
                 }
                 System.out.println();
                 break;
      }
   }
   
   private static void cmdline(String[] args)
   {
      try
      {
         context.setCurrentTraceFilename(args[0]);
         context.setJdktype(args[1]);
         
         File inputFile = new File(args[0]);
         FileReader reader = new FileReader(inputFile);
         
         ICollector c = CollectorFactory.getInstance().getCollector(args[1]);
         gcList = c.getGCList(reader);
         
         TextSummary ts = new TextSummary(gcList);
         ts.printSummary();
         
	      HistogramModel model = new HistogramModel(gcList);
	      JFrame frame = new GCAFrame(context);	
         frame.getContentPane().add(new IntegerHistogram(model));	   	
	  	   frame.setSize(450, 450);
	  	   frame.setVisible(true);
      }
      catch (IOException e)
      {
      	System.out.println("IOException: " + e);
      }
   }
}
