package pfg.gca.collector;

import pfg.gca.collector.regexp.*;

/**
 * A factory for generating GC record collectors.  Different JVMs
 * sometimes format their verbose GC records differently.  This
 * requires that the type of collector be determined during runtime.
 * <p>
 * @author Paul Glezen
 */
public abstract class CollectorFactory
{
   /**
    * Return a collector compatible with the specified JDK.
    * <p>
    * @param jdk the vendor and version of the JDK
    */
   public abstract ICollector getCollector(String jdk);
   
   /**
    * Return the description of a particular collector.  This
    * is provided since certain verbose GC formats applied across
    * several JDKs.  A single small string wasn't sufficient to
    * convey all this information.  So the collector description
    * briefly lists the applicable JDKs.  This description will
    * appear JDK list panel.
    * <p>
    * @param jdkString the tag by which the collector is known
    * @return a description of the JDKs supported by this collector
    */
   public abstract String getCollectorDescription(String jdkString);
   
   /**
    * Return an array of JDK strings supported by the factory.
    */
   public abstract String[] getSupportedJDKs();
   
   /**
    * Return an instance of the default factory.  A new instance
    * is created with each call.  This is not a singleton pattern.
    */
   public static CollectorFactory getInstance()
   {
      return new pfg.gca.collector.regexp.RegExpCollectorFactory();
   }
}
