package pfg.gca.collector;

import java.io.IOException;
import java.io.Reader;
import java.util.List;

/**
 * A collector collects GC records from a raw verbose GC
 * stream.  Since verbose GC output is typically gathered
 * from system error, data unrelated to GC activity may
 * also appear.  Since the format of the raw verbose GC
 * data depend on the JDK version, a different implementation
 * is needed for each format.
 * <p>
 * @author Paul Glezen
 */
public interface ICollector
{
   /**
    * Convert raw verbose GC from the <code>Reader</code> to
    * a <code>List</code> of {@link pfg.gca.GCRecord}.
    */
   public List getGCList(Reader reader) throws IOException;
   
   /**
    * Describes which JDK versions this collector supports.
    */
   public String getDescription();
}
