package pfg.gca.models;

import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;

import pfg.gca.GCRecord;

/**
 * Store GC data in a histogram format.  This model is
 * a HashMap where each key represents a time <tt>t</tt>
 * in milliseconds and each value represents the quantity
 * of GCs of duration <tt>t</tt>.
 * 
 * @author Paul Glezen
 */
public class HistogramModel extends HashMap
{
   /**
    * Accept a list of raw GC data and convert it to 
    * a histogram format.
    * 
    * @param gcRecords a list of {@link pfg.gca.GCRecord}
    */
   public HistogramModel(List gcRecords)
   {
   	  super();
      Iterator iter = gcRecords.iterator();
      Integer gcLength = null;
      Integer currValue = null;
      GCRecord gcRec = null;
      while (iter.hasNext())
      {
      	gcRec = (GCRecord) iter.next();
      	gcLength = new Integer(gcRec.getTotalTime());
         currValue = (Integer) get(gcLength);
         if (currValue == null)
         {
         	put(gcLength, new Integer(1));
         }
         else
         {
         	put(gcLength, new Integer(currValue.intValue() + 1));
         }
      }
   }
}
