package pfg.gca.swing;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.io.IOException;

import javax.swing.JButton;
import javax.swing.JFileChooser;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JTextField;

import pfg.gca.Context;

/**
 * Provide a JPanel for acquiring the filename of a
 * verbose GC trace file.
 * <p>
 * @author Paul Glezen
 */
public class FilenamePanel extends JPanel
{
   private Context gcaContext = null;
   private JTextField filenameField = null;
   
   /**
    * Add a label, an entry field and a browse button to the panel.
    * <p>
    * @param the {@link pfg.gca.Context} used to retrieve previous values
    *       and store new values.
    */
   public FilenamePanel(Context context)
   {
      super();
      gcaContext = context;
    
      //  Field label.
      //  
      add(new JLabel("Filename: "));
      
      //  Entry field.
      if (gcaContext.getCurrentTraceFilename() == null)
         filenameField = new JTextField(30);
      else
         filenameField = new JTextField(gcaContext.getCurrentTraceFilename(), 30);
         
      filenameField.addActionListener(new ActionListener()
      {
         public void actionPerformed(ActionEvent evt)
         {
            gcaContext.setCurrentTraceFilename(filenameField.getText());
         }
      });
      add(filenameField);
      
      //  Browse button.
      //
      JButton browse = new JButton("Browse");
      browse.addActionListener(new ActionListener()
      {
         public void actionPerformed(ActionEvent evt)
         {
            String filename = gcaContext.getCurrentTraceFilename();
            JFileChooser chooser = null;
            if (filename != null)
            {
               chooser = new JFileChooser(filename);
            }
            else
            {
               chooser = new JFileChooser();
            }
            int option = chooser.showOpenDialog(FilenamePanel.this);
            if (option == JFileChooser.APPROVE_OPTION)
            {
               try
               {
                  filename = chooser.getSelectedFile().getCanonicalPath();
               }
               catch (IOException e)
               {
                  System.out.println("Could not construct path name.");
               }
               if (filename != null)
               {
                  filenameField.setText(filename);
                  gcaContext.setCurrentTraceFilename(filename);
               }
            }
         }
      });
      add(browse);
   }
   
   /**
    * Get the filename currently displayed in the filename field.
    */
   public String getFilename()
   {
      String result = null;
      if (filenameField != null)
      {
         result = filenameField.getText();
      }
      
      return result;
   }
}
