package pfg.gca.swing;

import java.awt.GridLayout;
import java.awt.event.ActionEvent;

import javax.swing.AbstractAction;
import javax.swing.ButtonGroup;
import javax.swing.JPanel;
import javax.swing.JRadioButton;
import javax.swing.border.TitledBorder;

import pfg.gca.Context;

/**
 * Displays a group of radial buttons to gather the desired
 * JDK type.  This <code>JPanel</code> was designed to be
 * placed inside {@link TraceChooser}.
 * <p>
 * @author Paul Glezen
 */
public class JdkTypePanel extends JPanel
{
   private Context gcaContext;
   private String  selectedJDK;
   
   /**
    * If JDK type related information exists in the
    * {@link pfg.gca.Context} instance, then use it
    * to populate the initial value.  A reference to
    * the context is retained for storing the resulting
    * selection.
    */
   public JdkTypePanel(Context context)
   {
      super(new GridLayout(0, 1));
      gcaContext = context;
      String jdk = gcaContext.getJdktype();
      String collectorDesc = null;
      
      ButtonGroup buttonGroup = new ButtonGroup();
      String[] jdkStrings = gcaContext.getCollectorFactory().getSupportedJDKs();
      JRadioButton radioButton = null;
      
      for (int i = 0; i < jdkStrings.length; i++)
      {
         collectorDesc = gcaContext.getCollectorFactory().getCollectorDescription(jdkStrings[i]);
         radioButton = new JRadioButton(collectorDesc);
         if (jdk != null  &&  jdk.equals(jdkStrings[i])) {
            radioButton.setSelected(true);
            selectedJDK = jdk;
         }
         radioButton.addActionListener(new JdkAction(jdkStrings[i], gcaContext));
         buttonGroup.add(radioButton);
         add(radioButton);
      }
      
      setBorder(new TitledBorder("Supported JDKs"));
   }
   
   /**
    * This extends <code>AbstractAction</code> to set the name
    * of the selected JDK.
    */
   class JdkAction extends AbstractAction
   {
      private String name;
      private Context context;
      
      public JdkAction(String name, Context context)
      {
         super(name);
         this.name    = name;
         this.context = context;
      }
      
      public void actionPerformed(ActionEvent evt)
      {
         context.setJdktype(name);
         selectedJDK = name;
      }
   }
    
   /**
    * Get a string representing the currently selected JDK.  If
    * no choice has been made, a null is returned.
    * <p>
    * @returns String representation of JDK selection
    */
   public String getSelectedJDK()
   {
      return selectedJDK;
   }  
}
