package pfg.gca.swing;

import java.awt.BorderLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.io.File;
import java.io.FileReader;
import java.io.IOException;
import java.util.List;

import javax.swing.JButton;
import javax.swing.JDialog;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JPanel;

import pfg.gca.Context;
import pfg.gca.collector.ICollector;

/**
 * Display a panel for acquiring the verbose GC trace filename
 * and JDK version.
 * <p>
 * @author Paul Glezen
 */
public class TraceChooser extends JDialog
{
   private Context gcaContext = null;
   private JLabel  statusLabel = null;
   private FilenamePanel filePanel = null;
   private JdkTypePanel  jdkPanel  = null;
   
   /**
    * Create a TraceChooser with a reference to a {@link Context}
    * provides and accepts trace information. 
    */
   public TraceChooser(JFrame parent, Context context)
   {
      super(parent, "Load Verbose GC Ouput", true);
      gcaContext = context;
      filePanel  = new FilenamePanel(gcaContext);
      jdkPanel   = new JdkTypePanel(gcaContext);
      
      getContentPane().setLayout(new BorderLayout());

      getContentPane().add(filePanel, BorderLayout.NORTH);
      getContentPane().add(jdkPanel,  BorderLayout.CENTER); 
           
      JPanel buttonPanel = new JPanel();

      JButton button = new JButton("Load");
      buttonPanel.add(button);
      button.addActionListener(new ActionListener()
      {
         public void actionPerformed(ActionEvent evt)
         {
            //  Load something.
            String filename = filePanel.getFilename();
            String jdk      = jdkPanel.getSelectedJDK();
            if (filename != null  &&  jdk != null)
            {
               gcaContext.setCurrentTraceFilename(filename);
               gcaContext.setJdktype(jdk);
               ICollector collector = gcaContext.getCollectorFactory().getCollector(jdk);
               try
               {
                  File inputFile    = new File(filename);
                  FileReader reader = new FileReader(inputFile);
                  List l = collector.getGCList(reader);
                  gcaContext.setGCList(l);
                  statusLabel.setText("Status: Loaded");
                  hide();
                  dispose();
               }
               catch(IOException ioe)
               {
                  statusLabel.setText("Error: Failed to read " + filename);
               }
            }
            else
            {
               StringBuffer message = new StringBuffer("Missing Values:");
               if (filename == null)
                  message.append(" filename");
               if (jdk == null)
                  message.append(" jdk");
               statusLabel.setText(message.toString());
            }
            pack();
         }
      });

      button = new JButton("Close");
      buttonPanel.add(button);
      button.addActionListener(new ActionListener()
      {
         public void actionPerformed(ActionEvent evt)
         {
            hide();
            dispose();
         }
      });
      
      statusLabel = new JLabel("Status:");
      buttonPanel.add(statusLabel);
      
      getContentPane().add(buttonPanel, BorderLayout.SOUTH);
      
      pack();
   }
}
