package pfg.gca.views;

import java.text.DateFormat;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.Iterator;
import java.util.List;

import pfg.gca.GCRecord;

/**
 * Summarize the list of {@link pfg.gca.GCRecord} instances.
 * <p>
 * @author Paul Glezen
 */
public class TextSummary
{
   private List records;
   
   public TextSummary(List records)
   {
   	this.records = records;
   }
   
   public void printSummary()
   {
   	GCRecord maxGCTime = null;
      Date   firstGCTime = null;
      Date    lastGCTime = null;
   	int  numOfCompacts = 0;
   	int       numOfGCs = 0;
   	long   totalGCTime = 0;
      long     totalTime = 0;
   	
   	if (records != null)
   	{
   		GCRecord gcRec = null;
   		Iterator iter = records.iterator();
   		while (iter.hasNext())
   		{
   			gcRec = (GCRecord) iter.next();
   			numOfGCs++;
   			totalGCTime += gcRec.getTotalTime();
   			if (maxGCTime == null  ||  gcRec.getTotalTime() > maxGCTime.getTotalTime())
   			   maxGCTime = gcRec;
   			if (gcRec.getCompactTime() > 0)
   			   numOfCompacts++;
            if (firstGCTime == null) {
               firstGCTime = gcRec.getStartTime();
            }
            lastGCTime = gcRec.getStartTime();
   			// System.out.println(gcRec);
   		}
         DateFormat dateFormat = new SimpleDateFormat("EEE, MMM dd, hh:mm:ss z");
         String  lastGCTimeStr = dateFormat.format(lastGCTime);
         String firstGCTimeStr = dateFormat.format(firstGCTime);
         long     lastGCTimeMS = lastGCTime.getTime();
         long    firstGCTimeMS = firstGCTime.getTime();
         long           gcPct = (totalGCTime * 100) / (lastGCTimeMS - firstGCTimeMS); 
   		System.out.println("\nSummary\n");
         System.out.println("First GC time: " + firstGCTimeStr);
         System.out.println("Last GC time:  " + lastGCTimeStr);
   		System.out.println("Total GCs: " + numOfGCs);
   		System.out.println("Total GC Time: " + totalGCTime + " msec");
   		System.out.println("Average GC Time: " + (totalGCTime / numOfGCs) + " msec");
         System.out.println("Percent GC Time: " + gcPct + "%");
   		System.out.println("Compactions: " + numOfCompacts);
   		System.out.println("Max GC time: " + maxGCTime.getTotalTime() + " msec on " + maxGCTime.getStartTime());
   	}
   }
}
